@@ -12,6 +12,6 @@ class TimestampCacheKey extends CacheKey
     /** @param string $space Result cache id */
     public function __construct($space)
     {
-        $this->hash = (string) $space;
+        parent::__construct((string) $space);
     }
 }
