@@ -8,6 +8,7 @@ use Doctrine\Common\EventManager;
 use Doctrine\DBAL\Cache\QueryCacheProfile;
 use Doctrine\DBAL\Connection;
 use Doctrine\DBAL\Driver\PDO\SQLite\Driver;
+use Doctrine\DBAL\DriverManager;
 use Doctrine\DBAL\Result;
 use Doctrine\ORM\Configuration;
 use Doctrine\ORM\EntityManager;
@@ -16,6 +17,7 @@ use Doctrine\ORM\ORMSetup;
 use Doctrine\ORM\Proxy\ProxyFactory;
 use Doctrine\ORM\Tools\SchemaTool;
 use Doctrine\Tests\Mocks\DriverResultMock;
+use Doctrine\Tests\TestUtil;
 
 use function array_map;
 use function realpath;
@@ -26,19 +28,18 @@ final class EntityManagerFactory
     {
         $config = new Configuration();
 
-        $config->setProxyDir(__DIR__ . '/../Tests/Proxies');
-        $config->setProxyNamespace('Doctrine\Tests\Proxies');
+        TestUtil::configureProxies($config);
         $config->setAutoGenerateProxyClasses(ProxyFactory::AUTOGENERATE_EVAL);
         $config->setMetadataDriverImpl(ORMSetup::createDefaultAnnotationDriver([
             realpath(__DIR__ . '/Models/Cache'),
             realpath(__DIR__ . '/Models/GeoNames'),
         ]));
 
-        $entityManager = EntityManager::create(
-            [
+        $entityManager = new EntityManager(
+            DriverManager::getConnection([
                 'driverClass' => Driver::class,
                 'memory'      => true,
-            ],
+            ], $config),
             $config
         );
 
@@ -52,8 +53,7 @@ final class EntityManagerFactory
     {
         $config = new Configuration();
 
-        $config->setProxyDir(__DIR__ . '/../Tests/Proxies');
-        $config->setProxyNamespace('Doctrine\Tests\Proxies');
+        TestUtil::configureProxies($config);
         $config->setAutoGenerateProxyClasses(ProxyFactory::AUTOGENERATE_EVAL);
         $config->setMetadataDriverImpl(ORMSetup::createDefaultAnnotationDriver([
             realpath(__DIR__ . '/Models/Cache'),
@@ -71,6 +71,6 @@ final class EntityManagerFactory
             }
         };
 
-        return EntityManager::create($connection, $config, $connection->getEventManager());
+        return new EntityManager($connection, $config);
     }
 }
