@@ -5,54 +5,47 @@ declare(strict_types=1);
 namespace Doctrine\Tests\Mocks;
 
 use Doctrine\DBAL\Driver\Connection;
+use Doctrine\DBAL\Driver\Result;
 use Doctrine\DBAL\Driver\Statement;
-use PDO;
+use Doctrine\DBAL\ParameterType;
 
 /**
  * Mock class for DriverConnection.
  */
 class DriverConnectionMock implements Connection
 {
-    /** @var Statement|null */
-    private $statementMock;
+    /** @var Result|null */
+    private $resultMock;
 
-    public function getStatementMock(): ?Statement
+    public function setResultMock(?Result $resultMock): void
     {
-        return $this->statementMock;
-    }
-
-    public function setStatementMock(?Statement $statementMock): void
-    {
-        $this->statementMock = $statementMock;
+        $this->resultMock = $resultMock;
     }
 
     /**
      * {@inheritdoc}
      */
-    public function prepare($prepareString)
+    public function prepare($prepareString): Statement
     {
-        return $this->statementMock ?: new StatementMock();
+        return new StatementMock();
+    }
+
+    public function query(?string $sql = null): Result
+    {
+        return $this->resultMock ?? new DriverResultMock();
     }
 
     /**
      * {@inheritdoc}
      */
-    public function query()
-    {
-        return $this->statementMock ?: new StatementMock();
-    }
-
-    /**
-     * {@inheritdoc}
-     */
-    public function quote($input, $type = PDO::PARAM_STR)
+    public function quote($input, $type = ParameterType::STRING)
     {
     }
 
     /**
      * {@inheritdoc}
      */
-    public function exec($statement)
+    public function exec($statement): int
     {
     }
 
