@@ -4,7 +4,13 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\DDC2372;
 
-/** @Entity @Table(name="admins") */
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Table;
+
+/**
+ * @Entity
+ * @Table(name="admins")
+ */
 class DDC2372Admin extends DDC2372User
 {
 }
