@@ -1,11 +1,15 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\GH7316;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Collections\Collection;
 
 class GH7316Article
 {
+    /** @psalm-var Collection<int, mixed> */
     private $tags;
 
     public function __construct()
