@@ -4,6 +4,9 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\OneToOneSingleTableInheritance;
 
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\OneToOne;
+
 /** @Entity */
 class Cat extends Pet
 {
