@@ -1,5 +1,7 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\Models\Reflection;
 
 /**
@@ -7,5 +9,6 @@ namespace Doctrine\Tests\Models\Reflection;
  */
 class ConcreteEmbeddable extends AbstractEmbeddable
 {
+    /** @var string */
     private $propertyInConcreteClass;
 }
