@@ -4,6 +4,13 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\Taxi;
 
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\JoinColumn;
+use Doctrine\ORM\Mapping\ManyToOne;
+use Doctrine\ORM\Mapping\Table;
+
 /**
  * Same as Ride but with an extra column that is not part of the composite primary key
  *
