@@ -4,6 +4,14 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\Models\VersionedOneToOne;
 
+use Doctrine\ORM\Mapping\Column;
+use Doctrine\ORM\Mapping\Entity;
+use Doctrine\ORM\Mapping\Id;
+use Doctrine\ORM\Mapping\JoinColumn;
+use Doctrine\ORM\Mapping\OneToOne;
+use Doctrine\ORM\Mapping\Table;
+use Doctrine\ORM\Mapping\Version;
+
 /**
  * @Entity
  * @Table(name="first_entity")
