@@ -4,10 +4,10 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM;
 
+use Doctrine\Common\Annotations\SimpleAnnotationReader;
 use Doctrine\Common\Cache\ArrayCache;
 use Doctrine\Common\Cache\Cache;
 use Doctrine\Common\Cache\Psr6\CacheAdapter;
-use Doctrine\Common\Proxy\AbstractProxyFactory;
 use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use Doctrine\ORM\Cache\CacheConfiguration;
 use Doctrine\ORM\Cache\Exception\MetadataCacheNotConfigured;
@@ -20,10 +20,12 @@ use Doctrine\ORM\Exception\InvalidEntityRepository;
 use Doctrine\ORM\Exception\ORMException;
 use Doctrine\ORM\Exception\ProxyClassesAlwaysRegenerating;
 use Doctrine\ORM\Mapping as AnnotationNamespace;
+use Doctrine\ORM\Mapping\DefaultTypedFieldMapper;
 use Doctrine\ORM\Mapping\EntityListenerResolver;
 use Doctrine\ORM\Mapping\NamingStrategy;
 use Doctrine\ORM\Mapping\PrePersist;
 use Doctrine\ORM\Mapping\QuoteStrategy;
+use Doctrine\ORM\Proxy\ProxyFactory;
 use Doctrine\ORM\Query\ResultSetMapping;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use Doctrine\Persistence\ObjectRepository;
@@ -49,6 +51,7 @@ class ConfigurationTest extends DoctrineTestCase
     protected function setUp(): void
     {
         parent::setUp();
+
         $this->configuration = new Configuration();
     }
 
@@ -62,16 +65,16 @@ class ConfigurationTest extends DoctrineTestCase
 
     public function testSetGetAutoGenerateProxyClasses(): void
     {
-        self::assertSame(AbstractProxyFactory::AUTOGENERATE_ALWAYS, $this->configuration->getAutoGenerateProxyClasses()); // defaults
+        self::assertSame(ProxyFactory::AUTOGENERATE_ALWAYS, $this->configuration->getAutoGenerateProxyClasses()); // defaults
 
         $this->configuration->setAutoGenerateProxyClasses(false);
-        self::assertSame(AbstractProxyFactory::AUTOGENERATE_NEVER, $this->configuration->getAutoGenerateProxyClasses());
+        self::assertSame(ProxyFactory::AUTOGENERATE_NEVER, $this->configuration->getAutoGenerateProxyClasses());
 
         $this->configuration->setAutoGenerateProxyClasses(true);
-        self::assertSame(AbstractProxyFactory::AUTOGENERATE_ALWAYS, $this->configuration->getAutoGenerateProxyClasses());
+        self::assertSame(ProxyFactory::AUTOGENERATE_ALWAYS, $this->configuration->getAutoGenerateProxyClasses());
 
-        $this->configuration->setAutoGenerateProxyClasses(AbstractProxyFactory::AUTOGENERATE_FILE_NOT_EXISTS);
-        self::assertSame(AbstractProxyFactory::AUTOGENERATE_FILE_NOT_EXISTS, $this->configuration->getAutoGenerateProxyClasses());
+        $this->configuration->setAutoGenerateProxyClasses(ProxyFactory::AUTOGENERATE_FILE_NOT_EXISTS);
+        self::assertSame(ProxyFactory::AUTOGENERATE_FILE_NOT_EXISTS, $this->configuration->getAutoGenerateProxyClasses());
     }
 
     public function testSetGetProxyNamespace(): void
@@ -103,6 +106,16 @@ class ConfigurationTest extends DoctrineTestCase
             AnnotationNamespace\PrePersist::class
         );
         self::assertInstanceOf(AnnotationNamespace\PrePersist::class, $annotation);
+    }
+
+    public function testNewDefaultAnnotationDriverWithSimpleAnnotationReader(): void
+    {
+        if (! class_exists(SimpleAnnotationReader::class)) {
+            self::markTestSkipped('Requires doctrine/annotations 1.x');
+        }
+
+        $paths           = [__DIR__];
+        $reflectionClass = new ReflectionClass(ConfigurationTestAnnotationReaderChecker::class);
 
         $annotationDriver = $this->configuration->newDefaultAnnotationDriver($paths);
         $reader           = $annotationDriver->getReader();
@@ -211,7 +224,7 @@ class ConfigurationTest extends DoctrineTestCase
      */
     protected function setProductionSettings(?string $skipCache = null): void
     {
-        $this->configuration->setAutoGenerateProxyClasses(AbstractProxyFactory::AUTOGENERATE_NEVER);
+        $this->configuration->setAutoGenerateProxyClasses(ProxyFactory::AUTOGENERATE_NEVER);
 
         $cache = $this->createMock(Cache::class);
 
@@ -295,7 +308,7 @@ class ConfigurationTest extends DoctrineTestCase
     public function testEnsureProductionSettingsAutoGenerateProxyClassesAlways(): void
     {
         $this->setProductionSettings();
-        $this->configuration->setAutoGenerateProxyClasses(AbstractProxyFactory::AUTOGENERATE_ALWAYS);
+        $this->configuration->setAutoGenerateProxyClasses(ProxyFactory::AUTOGENERATE_ALWAYS);
 
         $this->expectException(ProxyClassesAlwaysRegenerating::class);
         $this->expectExceptionMessage('Proxy Classes are always regenerating.');
@@ -306,7 +319,7 @@ class ConfigurationTest extends DoctrineTestCase
     public function testEnsureProductionSettingsAutoGenerateProxyClassesFileNotExists(): void
     {
         $this->setProductionSettings();
-        $this->configuration->setAutoGenerateProxyClasses(AbstractProxyFactory::AUTOGENERATE_FILE_NOT_EXISTS);
+        $this->configuration->setAutoGenerateProxyClasses(ProxyFactory::AUTOGENERATE_FILE_NOT_EXISTS);
 
         $this->expectException(ORMException::class);
         $this->expectExceptionMessage('Proxy Classes are always regenerating.');
@@ -317,7 +330,7 @@ class ConfigurationTest extends DoctrineTestCase
     public function testEnsureProductionSettingsAutoGenerateProxyClassesEval(): void
     {
         $this->setProductionSettings();
-        $this->configuration->setAutoGenerateProxyClasses(AbstractProxyFactory::AUTOGENERATE_EVAL);
+        $this->configuration->setAutoGenerateProxyClasses(ProxyFactory::AUTOGENERATE_EVAL);
 
         $this->expectException(ORMException::class);
         $this->expectExceptionMessage('Proxy Classes are always regenerating.');
@@ -439,6 +452,15 @@ class ConfigurationTest extends DoctrineTestCase
         $this->configuration->setSecondLevelCacheConfiguration($mockClass);
         self::assertEquals($mockClass, $this->configuration->getSecondLevelCacheConfiguration());
     }
+
+    /** @group GH10313 */
+    public function testSetGetTypedFieldMapper(): void
+    {
+        self::assertEmpty($this->configuration->getTypedFieldMapper());
+        $defaultTypedFieldMapper = new DefaultTypedFieldMapper();
+        $this->configuration->setTypedFieldMapper($defaultTypedFieldMapper);
+        self::assertSame($defaultTypedFieldMapper, $this->configuration->getTypedFieldMapper());
+    }
 }
 
 class ConfigurationTestAnnotationReaderChecker
