@@ -21,15 +21,23 @@ class EntityNotFoundExceptionTest extends TestCase
             ['foo' => 'bar']
         );
 
-        $this->assertInstanceOf(EntityNotFoundException::class, $exception);
-        $this->assertSame('Entity of type \'foo\' for IDs foo(bar) was not found', $exception->getMessage());
+        self::assertInstanceOf(EntityNotFoundException::class, $exception);
+        self::assertSame('Entity of type \'foo\' for IDs foo(bar) was not found', $exception->getMessage());
 
         $exception = EntityNotFoundException::fromClassNameAndIdentifier(
             'foo',
             []
         );
 
-        $this->assertInstanceOf(EntityNotFoundException::class, $exception);
-        $this->assertSame('Entity of type \'foo\' was not found', $exception->getMessage());
+        self::assertInstanceOf(EntityNotFoundException::class, $exception);
+        self::assertSame('Entity of type \'foo\' was not found', $exception->getMessage());
+    }
+
+    public function testNoIdentifierFound(): void
+    {
+        $exception = EntityNotFoundException::noIdentifierFound('foo');
+
+        self::assertInstanceOf(EntityNotFoundException::class, $exception);
+        self::assertSame('Unable to find "foo" entity identifier associated with the UnitOfWork', $exception->getMessage());
     }
 }
