@@ -8,9 +8,9 @@ use Doctrine\ORM\EntityNotFoundException;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\ORMInvalidArgumentException;
 use Doctrine\ORM\PersistentCollection;
-use Doctrine\ORM\Proxy\Proxy;
 use Doctrine\ORM\Query;
 use Doctrine\ORM\UnitOfWork;
+use Doctrine\Persistence\Proxy;
 use Doctrine\Tests\IterableTester;
 use Doctrine\Tests\Models\CMS\CmsAddress;
 use Doctrine\Tests\Models\CMS\CmsArticle;
@@ -27,6 +27,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
     protected function setUp(): void
     {
         $this->useModelSet('cms');
+
         parent::setUp();
     }
 
@@ -708,7 +709,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
 
         self::assertInstanceOf(Proxy::class, $address2->getUser());
         self::assertTrue($userRef === $address2->getUser());
-        self::assertFalse($userRef->__isInitialized__);
+        self::assertFalse($userRef->__isInitialized());
         self::assertEquals('Germany', $address2->country);
         self::assertEquals('Berlin', $address2->city);
         self::assertEquals('12345', $address2->zip);
@@ -1006,7 +1007,7 @@ class BasicFunctionalTest extends OrmFunctionalTestCase
                              ->setFetchMode(CmsArticle::class, 'user', ClassMetadata::FETCH_EAGER)
                              ->getSingleResult();
         self::assertInstanceOf(Proxy::class, $article->user, 'It IS a proxy, ...');
-        self::assertTrue($article->user->__isInitialized__, '...but its initialized!');
+        self::assertTrue($article->user->__isInitialized(), '...but its initialized!');
         $this->assertQueryCount(2);
     }
 
