@@ -13,8 +13,6 @@ use Doctrine\ORM\Query\SqlWalker;
 use Doctrine\Tests\Models\CMS\CmsUser;
 use Doctrine\Tests\OrmFunctionalTestCase;
 
-use function count;
-
 require_once __DIR__ . '/../../TestInit.php';
 
 class CustomFunctionsTest extends OrmFunctionalTestCase
@@ -48,8 +46,8 @@ class CustomFunctionsTest extends OrmFunctionalTestCase
 
         $users = $query->getResult();
 
-        $this->assertEquals(1, count($users));
-        $this->assertSame($user, $users[0]);
+        self::assertCount(1, $users);
+        self::assertSame($user, $users[0]);
     }
 
     public function testCustomFunctionOverride(): void
@@ -66,7 +64,7 @@ class CustomFunctionsTest extends OrmFunctionalTestCase
 
         $usersCount = $query->getSingleScalarResult();
 
-        $this->assertEquals(1, $usersCount);
+        self::assertEquals(1, $usersCount);
     }
 }
 
