@@ -4,7 +4,7 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Functional;
 
-use Doctrine\ORM\Proxy\Proxy;
+use Doctrine\Persistence\Proxy;
 use Doctrine\Tests\Models\DirectoryTree\Directory;
 use Doctrine\Tests\Models\DirectoryTree\File;
 use Doctrine\Tests\OrmFunctionalTestCase;
@@ -19,6 +19,7 @@ class MappedSuperclassTest extends OrmFunctionalTestCase
     protected function setUp(): void
     {
         $this->useModelSet('directorytree');
+
         parent::setUp();
     }
 
