@@ -10,12 +10,13 @@ use Doctrine\ORM\Configuration;
 use Doctrine\ORM\EntityManager;
 use Doctrine\ORM\EntityManagerInterface;
 use Doctrine\ORM\ORMSetup;
-use Doctrine\ORM\Proxy\Proxy;
 use Doctrine\ORM\Tools\SchemaTool;
+use Doctrine\Persistence\Proxy;
 use Doctrine\Tests\DbalExtensions\Connection;
 use Doctrine\Tests\DbalExtensions\QueryLog;
 use Doctrine\Tests\Models\Generic\DateTimeModel;
 use Doctrine\Tests\OrmFunctionalTestCase;
+use Doctrine\Tests\TestUtil;
 
 use function assert;
 use function realpath;
@@ -239,8 +240,7 @@ class MergeProxiesTest extends OrmFunctionalTestCase
     {
         $config = new Configuration();
 
-        $config->setProxyDir(realpath(__DIR__ . '/../../Proxies'));
-        $config->setProxyNamespace('Doctrine\Tests\Proxies');
+        TestUtil::configureProxies($config);
         $config->setMetadataDriverImpl(ORMSetup::createDefaultAnnotationDriver(
             [realpath(__DIR__ . '/../../Models/Cache')]
         ));
@@ -257,7 +257,7 @@ class MergeProxiesTest extends OrmFunctionalTestCase
             $config
         );
 
-        $entityManager = EntityManager::create($connection, $config);
+        $entityManager = new EntityManager($connection, $config);
 
         (new SchemaTool($entityManager))->createSchema([$entityManager->getClassMetadata(DateTimeModel::class)]);
 
