@@ -6,7 +6,7 @@ namespace Doctrine\Tests\ORM\Functional;
 
 use Doctrine\Common\Collections\Collection;
 use Doctrine\Common\Collections\Criteria;
-use Doctrine\ORM\Proxy\Proxy;
+use Doctrine\Persistence\Proxy;
 use Doctrine\Tests\Models\ECommerce\ECommerceFeature;
 use Doctrine\Tests\Models\ECommerce\ECommerceProduct;
 use Doctrine\Tests\OrmFunctionalTestCase;
@@ -28,7 +28,9 @@ class OneToManyBidirectionalAssociationTest extends OrmFunctionalTestCase
     protected function setUp(): void
     {
         $this->useModelSet('ecommerce');
+
         parent::setUp();
+
         $this->product = new ECommerceProduct();
         $this->product->setName('Doctrine Cookbook');
         $this->firstFeature = new ECommerceFeature();
@@ -126,9 +128,9 @@ class OneToManyBidirectionalAssociationTest extends OrmFunctionalTestCase
         $product = $features[0]->getProduct();
         self::assertInstanceOf(Proxy::class, $product);
         self::assertInstanceOf(ECommerceProduct::class, $product);
-        self::assertFalse($product->__isInitialized__);
+        self::assertFalse($product->__isInitialized());
         self::assertSame('Doctrine Cookbook', $product->getName());
-        self::assertTrue($product->__isInitialized__);
+        self::assertTrue($product->__isInitialized());
     }
 
     public function testLazyLoadsObjectsOnTheInverseSide2(): void
