@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Functional;
 
+use Doctrine\Common\Proxy\Proxy as CommonProxy;
 use Doctrine\Common\Util\ClassUtils;
 use Doctrine\Persistence\Proxy;
 use Doctrine\Tests\Models\Company\CompanyAuction;
@@ -29,6 +30,7 @@ class ReferenceProxyTest extends OrmFunctionalTestCase
     {
         $this->useModelSet('ecommerce');
         $this->useModelSet('company');
+
         parent::setUp();
     }
 
@@ -118,9 +120,9 @@ class ReferenceProxyTest extends OrmFunctionalTestCase
         $entity = $this->_em->getReference(ECommerceProduct::class, $id);
         assert($entity instanceof ECommerceProduct);
 
-        self::assertFalse($entity->__isInitialized__, 'Pre-Condition: Object is unitialized proxy.');
+        self::assertFalse($entity->__isInitialized(), 'Pre-Condition: Object is unitialized proxy.');
         $this->_em->getUnitOfWork()->initializeObject($entity);
-        self::assertTrue($entity->__isInitialized__, 'Should be initialized after called UnitOfWork::initializeObject()');
+        self::assertTrue($entity->__isInitialized(), 'Should be initialized after called UnitOfWork::initializeObject()');
     }
 
     /** @group DDC-1163 */
@@ -140,7 +142,7 @@ class ReferenceProxyTest extends OrmFunctionalTestCase
     }
 
     /** @group DDC-1022 */
-    public function testWakeupCalledOnProxy(): void
+    public function testWakeupOnProxy(): void
     {
         $id = $this->createProduct();
 
@@ -151,7 +153,11 @@ class ReferenceProxyTest extends OrmFunctionalTestCase
 
         $entity->setName('Doctrine 2 Cookbook');
 
-        self::assertTrue($entity->wakeUp, 'Loading the proxy should call __wakeup().');
+        if ($entity instanceof CommonProxy) {
+            self::assertTrue($entity->wakeUp, 'Loading the proxy should call __wakeup().');
+        } else {
+            self::assertFalse($entity->wakeUp, 'Loading the proxy should call __wakeup().');
+        }
     }
 
     public function testDoNotInitializeProxyOnGettingTheIdentifier(): void
@@ -161,9 +167,9 @@ class ReferenceProxyTest extends OrmFunctionalTestCase
         $entity = $this->_em->getReference(ECommerceProduct::class, $id);
         assert($entity instanceof ECommerceProduct);
 
-        self::assertFalse($entity->__isInitialized__, 'Pre-Condition: Object is unitialized proxy.');
+        self::assertFalse($entity->__isInitialized(), 'Pre-Condition: Object is unitialized proxy.');
         self::assertEquals($id, $entity->getId());
-        self::assertFalse($entity->__isInitialized__, "Getting the identifier doesn't initialize the proxy.");
+        self::assertFalse($entity->__isInitialized(), "Getting the identifier doesn't initialize the proxy.");
     }
 
     /** @group DDC-1625 */
@@ -174,9 +180,9 @@ class ReferenceProxyTest extends OrmFunctionalTestCase
         $entity = $this->_em->getReference(CompanyAuction::class, $id);
         assert($entity instanceof CompanyAuction);
 
-        self::assertFalse($entity->__isInitialized__, 'Pre-Condition: Object is unitialized proxy.');
+        self::assertFalse($entity->__isInitialized(), 'Pre-Condition: Object is unitialized proxy.');
         self::assertEquals($id, $entity->getId());
-        self::assertFalse($entity->__isInitialized__, "Getting the identifier doesn't initialize the proxy when extending.");
+        self::assertFalse($entity->__isInitialized(), "Getting the identifier doesn't initialize the proxy when extending.");
     }
 
     public function testDoNotInitializeProxyOnGettingTheIdentifierAndReturnTheRightType(): void
@@ -196,10 +202,10 @@ class ReferenceProxyTest extends OrmFunctionalTestCase
         $product = $this->_em->getRepository(ECommerceProduct::class)->find($product->getId());
 
         $entity = $product->getShipping();
-        self::assertFalse($entity->__isInitialized__, 'Pre-Condition: Object is unitialized proxy.');
+        self::assertFalse($entity->__isInitialized(), 'Pre-Condition: Object is unitialized proxy.');
         self::assertEquals($id, $entity->getId());
         self::assertSame($id, $entity->getId(), "Check that the id's are the same value, and type.");
-        self::assertFalse($entity->__isInitialized__, "Getting the identifier doesn't initialize the proxy.");
+        self::assertFalse($entity->__isInitialized(), "Getting the identifier doesn't initialize the proxy.");
     }
 
     public function testInitializeProxyOnGettingSomethingOtherThanTheIdentifier(): void
@@ -209,9 +215,9 @@ class ReferenceProxyTest extends OrmFunctionalTestCase
         $entity = $this->_em->getReference(ECommerceProduct::class, $id);
         assert($entity instanceof ECommerceProduct);
 
-        self::assertFalse($entity->__isInitialized__, 'Pre-Condition: Object is unitialized proxy.');
+        self::assertFalse($entity->__isInitialized(), 'Pre-Condition: Object is unitialized proxy.');
         self::assertEquals('Doctrine Cookbook', $entity->getName());
-        self::assertTrue($entity->__isInitialized__, 'Getting something other than the identifier initializes the proxy.');
+        self::assertTrue($entity->__isInitialized(), 'Getting something other than the identifier initializes the proxy.');
     }
 
     /** @group DDC-1604 */
