@@ -4,7 +4,7 @@ declare(strict_types=1);
 
 namespace Doctrine\Tests\ORM\Functional\Ticket;
 
-use Doctrine\ORM\Proxy\Proxy;
+use Doctrine\Persistence\Proxy;
 use Doctrine\Tests\Models\Legacy\LegacyUser;
 use Doctrine\Tests\Models\Legacy\LegacyUserReference;
 use Doctrine\Tests\OrmFunctionalTestCase;
@@ -15,6 +15,7 @@ class DDC2519Test extends OrmFunctionalTestCase
     protected function setUp(): void
     {
         $this->useModelSet('legacy');
+
         parent::setUp();
 
         $this->loadFixture();
