@@ -19,6 +19,7 @@ use Doctrine\ORM\Mapping\MappedSuperclass;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\ORM\Mapping\ReflectionEmbeddedProperty;
 use Doctrine\ORM\Query\QueryException;
+use Doctrine\Persistence\Reflection\RuntimeReflectionProperty;
 use Doctrine\Tests\OrmFunctionalTestCase;
 use ReflectionProperty;
 
@@ -51,6 +52,11 @@ class ValueObjectsTest extends OrmFunctionalTestCase
                 CommonRuntimePublicReflectionProperty::class,
                 $classMetadata->getReflectionProperty('address')
             );
+        } elseif (class_exists(RuntimeReflectionProperty::class)) {
+            self::assertInstanceOf(
+                RuntimeReflectionProperty::class,
+                $classMetadata->getReflectionProperty('address')
+            );
         } else {
             self::assertInstanceOf(
                 ReflectionProperty::class,
