@@ -6,8 +6,8 @@ namespace Doctrine\Tests\ORM\Mapping;
 
 use Attribute;
 use Doctrine\ORM\Mapping as ORM;
-use Doctrine\ORM\Mapping\Annotation;
 use Doctrine\ORM\Mapping\Driver\AttributeDriver;
+use Doctrine\ORM\Mapping\MappingAttribute;
 use Doctrine\Persistence\Mapping\Driver\AnnotationDriver as PersistenceAnnotationDriver;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use stdClass;
@@ -130,14 +130,16 @@ class AttributeDriverTest extends MappingDriverTestCase
 #[ORM\Index(name: 'bar', columns: ['id'])]
 class AttributeEntityWithoutOriginalParents
 {
-    #[ORM\Id, ORM\Column(type: 'integer'), ORM\GeneratedValue]
     /** @var int */
+    #[ORM\Id]
+    #[ORM\Column(type: 'integer')]
+    #[ORM\GeneratedValue]
     public $id;
 
+    /** @var AttributeEntityWithoutOriginalParents[] */
     #[ORM\ManyToMany(targetEntity: self::class)]
     #[ORM\JoinColumn(name: 'assoz_id', referencedColumnName: 'assoz_id')]
     #[ORM\InverseJoinColumn(name: 'assoz_id', referencedColumnName: 'assoz_id')]
-    /** @var AttributeEntityWithoutOriginalParents[] */
     public $assoc;
 }
 
@@ -149,7 +151,7 @@ class AttributeEntityStartingWithRepeatableAttributes
 }
 
 #[Attribute(Attribute::IS_REPEATABLE | Attribute::TARGET_ALL)]
-class AttributeTransientAnnotation implements Annotation
+class AttributeTransientAnnotation implements MappingAttribute
 {
 }
 
