@@ -40,6 +40,7 @@ use Doctrine\Tests\Models\JoinedInheritanceType\RootClass;
 use Doctrine\Tests\Models\Quote;
 use Doctrine\Tests\OrmTestCase;
 use Doctrine\Tests\PHPUnitCompatibility\MockBuilderCompatibilityTools;
+use Doctrine\Tests\TestUtil;
 use Exception;
 use InvalidArgumentException;
 use PHPUnit\Framework\Assert;
@@ -283,8 +284,7 @@ class ClassMetadataFactoryTest extends OrmTestCase
     protected function createEntityManager(MappingDriver $metadataDriver, $conn = null): EntityManagerMock
     {
         $config = new Configuration();
-        $config->setProxyDir(__DIR__ . '/../../Proxies');
-        $config->setProxyNamespace('Doctrine\Tests\Proxies');
+        TestUtil::configureProxies($config);
         $eventManager = new EventManager();
         if (! $conn) {
             $platform = $this->createMock(AbstractPlatform::class);
@@ -300,7 +300,7 @@ class ClassMetadataFactoryTest extends OrmTestCase
 
         $config->setMetadataDriverImpl($metadataDriver);
 
-        return EntityManagerMock::create($conn, $config);
+        return new EntityManagerMock($conn, $config);
     }
 
     protected function createTestFactory(): ClassMetadataFactoryTestSubject
