@@ -5,15 +5,21 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Mapping;
 
 use ArrayObject;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Events;
+use Doctrine\ORM\Mapping\ChainTypedFieldMapper;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\Mapping\Column;
 use Doctrine\ORM\Mapping\DefaultNamingStrategy;
+use Doctrine\ORM\Mapping\DefaultTypedFieldMapper;
 use Doctrine\ORM\Mapping\MappedSuperclass;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\ORM\Mapping\UnderscoreNamingStrategy;
 use Doctrine\Persistence\Mapping\RuntimeReflectionService;
 use Doctrine\Persistence\Mapping\StaticReflectionService;
+use Doctrine\Tests\DbalTypes\CustomIdObject;
+use Doctrine\Tests\DbalTypes\CustomIdObjectType;
+use Doctrine\Tests\DbalTypes\CustomIntType;
 use Doctrine\Tests\Models\CMS;
 use Doctrine\Tests\Models\CMS\CmsEmail;
 use Doctrine\Tests\Models\Company\CompanyContract;
@@ -25,6 +31,7 @@ use Doctrine\Tests\Models\DDC964\DDC964Admin;
 use Doctrine\Tests\Models\DDC964\DDC964Guest;
 use Doctrine\Tests\Models\Routing\RoutingLeg;
 use Doctrine\Tests\Models\TypedProperties;
+use Doctrine\Tests\ORM\Mapping\TypedFieldMapper\CustomIntAsStringTypedFieldMapper;
 use Doctrine\Tests\OrmTestCase;
 use DoctrineGlobalArticle;
 use ReflectionClass;
@@ -177,6 +184,52 @@ class ClassMetadataTest extends OrmTestCase
         self::assertEquals('float', $cm->getTypeOfField('float'));
     }
 
+    /**
+     * @group GH10313
+     * @requires PHP 7.4
+     */
+    public function testFieldTypeFromReflectionDefaultTypedFieldMapper(): void
+    {
+        $cm = new ClassMetadata(
+            TypedProperties\UserTypedWithCustomTypedField::class,
+            null,
+            new DefaultTypedFieldMapper(
+                [
+                    CustomIdObject::class => CustomIdObjectType::class,
+                    'int' => CustomIntType::class,
+                ]
+            )
+        );
+        $cm->initializeReflection(new RuntimeReflectionService());
+
+        $cm->mapField(['fieldName' => 'customId']);
+        $cm->mapField(['fieldName' => 'customIntTypedField']);
+        self::assertEquals(CustomIdObjectType::class, $cm->getTypeOfField('customId'));
+        self::assertEquals(CustomIntType::class, $cm->getTypeOfField('customIntTypedField'));
+    }
+
+    /**
+     * @group GH10313
+     * @requires PHP 7.4
+     */
+    public function testFieldTypeFromReflectionChainTypedFieldMapper(): void
+    {
+        $cm = new ClassMetadata(
+            TypedProperties\UserTyped::class,
+            null,
+            new ChainTypedFieldMapper(
+                new CustomIntAsStringTypedFieldMapper(),
+                new DefaultTypedFieldMapper()
+            )
+        );
+        $cm->initializeReflection(new RuntimeReflectionService());
+
+        $cm->mapField(['fieldName' => 'id']);
+        $cm->mapField(['fieldName' => 'username']);
+        self::assertEquals(Types::STRING, $cm->getTypeOfField('id'));
+        self::assertEquals(Types::STRING, $cm->getTypeOfField('username'));
+    }
+
     /** @group DDC-115 */
     public function testMapAssociationInGlobalNamespace(): void
     {
