@@ -13,6 +13,7 @@ use Doctrine\ORM\Mapping\ClassMetadataFactory;
 use Doctrine\ORM\Mapping\Column;
 use Doctrine\ORM\Mapping\CustomIdGenerator;
 use Doctrine\ORM\Mapping\DefaultNamingStrategy;
+use Doctrine\ORM\Mapping\DefaultTypedFieldMapper;
 use Doctrine\ORM\Mapping\DiscriminatorColumn;
 use Doctrine\ORM\Mapping\DiscriminatorMap;
 use Doctrine\ORM\Mapping\Entity;
@@ -27,6 +28,7 @@ use Doctrine\ORM\Mapping\ManyToMany;
 use Doctrine\ORM\Mapping\MappingException;
 use Doctrine\ORM\Mapping\NamedQueries;
 use Doctrine\ORM\Mapping\NamedQuery;
+use Doctrine\ORM\Mapping\NamingStrategy;
 use Doctrine\ORM\Mapping\OneToMany;
 use Doctrine\ORM\Mapping\OneToOne;
 use Doctrine\ORM\Mapping\OrderBy;
@@ -34,11 +36,15 @@ use Doctrine\ORM\Mapping\PostPersist;
 use Doctrine\ORM\Mapping\PrePersist;
 use Doctrine\ORM\Mapping\SequenceGenerator;
 use Doctrine\ORM\Mapping\Table;
+use Doctrine\ORM\Mapping\TypedFieldMapper;
 use Doctrine\ORM\Mapping\UnderscoreNamingStrategy;
 use Doctrine\ORM\Mapping\UniqueConstraint;
 use Doctrine\ORM\Mapping\Version;
 use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use Doctrine\Persistence\Mapping\RuntimeReflectionService;
+use Doctrine\Tests\DbalTypes\CustomIdObject;
+use Doctrine\Tests\DbalTypes\CustomIdObjectType;
+use Doctrine\Tests\DbalTypes\CustomIntType;
 use Doctrine\Tests\Models\Cache\City;
 use Doctrine\Tests\Models\CMS\CmsAddress;
 use Doctrine\Tests\Models\CMS\CmsAddressListener;
@@ -65,8 +71,10 @@ use Doctrine\Tests\Models\DDC964\DDC964Admin;
 use Doctrine\Tests\Models\DDC964\DDC964Guest;
 use Doctrine\Tests\Models\Enums\Card;
 use Doctrine\Tests\Models\Enums\Suit;
+use Doctrine\Tests\Models\GH10288\GH10288People;
 use Doctrine\Tests\Models\TypedProperties\Contact;
 use Doctrine\Tests\Models\TypedProperties\UserTyped;
+use Doctrine\Tests\Models\TypedProperties\UserTypedWithCustomTypedField;
 use Doctrine\Tests\Models\Upsertable\Insertable;
 use Doctrine\Tests\Models\Upsertable\Updatable;
 use Doctrine\Tests\OrmTestCase;
@@ -85,12 +93,17 @@ abstract class MappingDriverTestCase extends OrmTestCase
 {
     abstract protected function loadDriver(): MappingDriver;
 
-    /** @psalm-param class-string<object> $entityClassName */
-    public function createClassMetadata(string $entityClassName): ClassMetadata
-    {
+    /**
+     * @psalm-param class-string<object> $entityClassName
+     */
+    public function createClassMetadata(
+        string $entityClassName,
+        ?NamingStrategy $namingStrategy = null,
+        ?TypedFieldMapper $typedFieldMapper = null
+    ): ClassMetadata {
         $mappingDriver = $this->loadDriver();
 
-        $class = new ClassMetadata($entityClassName);
+        $class = new ClassMetadata($entityClassName, $namingStrategy, $typedFieldMapper);
         $class->initializeReflection(new RuntimeReflectionService());
         $mappingDriver->loadMetadataForClass($entityClassName, $class);
 
@@ -270,12 +283,11 @@ abstract class MappingDriverTestCase extends OrmTestCase
         return $class;
     }
 
+    /**
+     * @requires PHP 7.4
+     */
     public function testFieldTypeFromReflection(): void
     {
-        if (PHP_VERSION_ID < 70400) {
-            self::markTestSkipped('requies PHP 7.4');
-        }
-
         $class = $this->createClassMetadata(UserTyped::class);
 
         self::assertEquals('integer', $class->getTypeOfField('id'));
@@ -292,6 +304,27 @@ abstract class MappingDriverTestCase extends OrmTestCase
         self::assertEquals(Contact::class, $class->embeddedClasses['contact']['class']);
     }
 
+    /**
+     * @group GH10313
+     * @requires PHP 7.4
+     */
+    public function testCustomFieldTypeFromReflection(): void
+    {
+        $class = $this->createClassMetadata(
+            UserTypedWithCustomTypedField::class,
+            null,
+            new DefaultTypedFieldMapper(
+                [
+                    CustomIdObject::class => CustomIdObjectType::class,
+                    'int' => CustomIntType::class,
+                ]
+            )
+        );
+
+        self::assertEquals(CustomIdObjectType::class, $class->getTypeOfField('customId'));
+        self::assertEquals(CustomIntType::class, $class->getTypeOfField('customIntTypedField'));
+    }
+
     /** @depends testEntityTableNameAndInheritance */
     public function testFieldOptions(ClassMetadata $class): ClassMetadata
     {
@@ -448,7 +481,7 @@ abstract class MappingDriverTestCase extends OrmTestCase
         $class = $this->createClassMetadata(Animal::class);
 
         self::assertEquals(
-            ['name' => 'discr', 'type' => 'string', 'length' => '32', 'fieldName' => 'discr', 'columnDefinition' => null],
+            ['name' => 'discr', 'type' => 'string', 'length' => 32, 'fieldName' => 'discr', 'columnDefinition' => null, 'enumType' => null],
             $class->discriminatorColumn
         );
     }
@@ -555,6 +588,20 @@ abstract class MappingDriverTestCase extends OrmTestCase
         self::assertEquals('dtype', $class->discriminatorColumn['name']);
     }
 
+    /**
+     * @group GH10288
+     */
+    public function testDiscriminatorColumnEnumTypeDefinition(): void
+    {
+        $class = $this->createClassMetadata(GH10288EnumTypePerson::class);
+
+        self::assertArrayHasKey('enumType', $class->discriminatorColumn);
+        self::assertArrayHasKey('name', $class->discriminatorColumn);
+
+        self::assertEquals(GH10288People::class, $class->discriminatorColumn['enumType']);
+        self::assertEquals('discr', $class->discriminatorColumn['name']);
+    }
+
     /** @group DDC-889 */
     public function testInvalidEntityOrMappedSuperClassShouldMentionParentClasses(): void
     {
@@ -1114,10 +1161,14 @@ abstract class MappingDriverTestCase extends OrmTestCase
  * )
  * @NamedQueries({@NamedQuery(name="all", query="SELECT u FROM __CLASS__ u")})
  */
-#[ORM\Entity(), ORM\HasLifecycleCallbacks()]
+#[ORM\Entity()]
+#[ORM\HasLifecycleCallbacks()]
 #[ORM\Table(name: 'cms_users', options: ['foo' => 'bar', 'baz' => ['key' => 'val']])]
-#[ORM\Index(name: 'name_idx', columns: ['name']), ORM\Index(name: '0', columns: ['user_email']), ORM\Index(name: 'fields', fields: ['name', 'email'])]
-#[ORM\UniqueConstraint(name: 'search_idx', columns: ['name', 'user_email'], options: ['where' => 'name IS NOT NULL']), ORM\UniqueConstraint(name: 'phone_idx', fields: ['name', 'phone'])]
+#[ORM\Index(name: 'name_idx', columns: ['name'])]
+#[ORM\Index(name: '0', columns: ['user_email'])]
+#[ORM\Index(name: 'fields', fields: ['name', 'email'])]
+#[ORM\UniqueConstraint(name: 'search_idx', columns: ['name', 'user_email'], options: ['where' => 'name IS NOT NULL'])]
+#[ORM\UniqueConstraint(name: 'phone_idx', fields: ['name', 'phone'])]
 class User
 {
     /**
@@ -1127,7 +1178,8 @@ class User
      * @GeneratedValue(strategy="AUTO")
      * @SequenceGenerator(sequenceName="tablename_seq", initialValue=1, allocationSize=100)
      **/
-    #[ORM\Id, ORM\Column(type: 'integer', options: ['foo' => 'bar', 'unsigned' => false])]
+    #[ORM\Id]
+    #[ORM\Column(type: 'integer', options: ['foo' => 'bar', 'unsigned' => false])]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     #[ORM\SequenceGenerator(sequenceName: 'tablename_seq', initialValue: 1, allocationSize: 100)]
     public $id;
@@ -1183,7 +1235,8 @@ class User
      * @Column(type="integer")
      * @Version
      */
-    #[ORM\Column(type: 'integer'), ORM\Version]
+    #[ORM\Column(type: 'integer')]
+    #[ORM\Version]
     public $version;
 
     /** @PrePersist */
@@ -1469,7 +1522,9 @@ class UserIncorrectUniqueConstraint
  * @DiscriminatorMap({"cat" = "Cat", "dog" = "Dog"})
  * @DiscriminatorColumn(name="discr", length=32, type="string")
  */
-#[ORM\Entity, ORM\InheritanceType('SINGLE_TABLE'), ORM\DiscriminatorColumn(name: 'discr', length: 32, type: 'string')]
+#[ORM\Entity]
+#[ORM\InheritanceType('SINGLE_TABLE')]
+#[ORM\DiscriminatorColumn(name: 'discr', length: 32, type: 'string')]
 #[ORM\DiscriminatorMap(['cat' => 'Cat', 'dog' => 'Dog'])]
 abstract class Animal
 {
@@ -1480,7 +1535,9 @@ abstract class Animal
      * @GeneratedValue(strategy="CUSTOM")
      * @CustomIdGenerator(class="stdClass")
      */
-    #[ORM\Id, ORM\Column(type: 'string'), ORM\GeneratedValue(strategy: 'CUSTOM')]
+    #[ORM\Id]
+    #[ORM\Column(type: 'string')]
+    #[ORM\GeneratedValue(strategy: 'CUSTOM')]
     #[ORM\CustomIdGenerator(class: 'stdClass')]
     public $id;
 
@@ -1524,10 +1581,11 @@ class DDC1170Entity
      * @GeneratedValue(strategy="NONE")
      * @Column(type="integer", columnDefinition = "INT unsigned NOT NULL")
      **/
-    #[ORM\Id, ORM\GeneratedValue(strategy: 'NONE'), ORM\Column(type: 'integer', columnDefinition: 'INT UNSIGNED NOT NULL')]
+    #[ORM\Id]
+    #[ORM\GeneratedValue(strategy: 'NONE')]
+    #[ORM\Column(type: 'integer', columnDefinition: 'INT UNSIGNED NOT NULL')]
     private $id;
 
-
     /**
      * @var string|null
      * @Column(columnDefinition = "VARCHAR(255) NOT NULL")
@@ -1572,7 +1630,8 @@ class DDC1170Entity
  * @DiscriminatorMap({"ONE" = "DDC807SubClasse1", "TWO" = "DDC807SubClasse2"})
  * @DiscriminatorColumn(name = "dtype", columnDefinition="ENUM('ONE','TWO')")
  */
-#[ORM\Entity, ORM\InheritanceType('SINGLE_TABLE')]
+#[ORM\Entity]
+#[ORM\InheritanceType('SINGLE_TABLE')]
 #[ORM\DiscriminatorColumn(name: 'dtype', columnDefinition: "ENUM('ONE','TWO')")]
 #[ORM\DiscriminatorMap(['ONE' => 'DDC807SubClasse1', 'TWO' => 'DDC807SubClasse2'])]
 class DDC807Entity
@@ -1583,7 +1642,9 @@ class DDC807Entity
      * @Column(type="integer")
      * @GeneratedValue(strategy="NONE")
      **/
-    #[ORM\Id, ORM\Column(type: 'integer'), ORM\GeneratedValue(strategy: 'NONE')]
+    #[ORM\Id]
+    #[ORM\Column(type: 'integer')]
+    #[ORM\GeneratedValue(strategy: 'NONE')]
     public $id;
 
     public static function loadMetadata(ClassMetadata $metadata): void
@@ -1628,7 +1689,8 @@ class Group
  * @Entity
  * @Table(indexes={@Index(columns={"content"}, flags={"fulltext"}, options={"where": "content IS NOT NULL"})})
  */
-#[ORM\Entity, ORM\Table(name: 'Comment')]
+#[ORM\Entity]
+#[ORM\Table(name: 'Comment')]
 #[ORM\Index(columns: ['content'], flags: ['fulltext'], options: ['where' => 'content IS NOT NULL'])]
 class Comment
 {
@@ -1673,7 +1735,8 @@ class Comment
  *     "TWO" = "SingleTableEntityNoDiscriminatorColumnMappingSub2"
  * })
  */
-#[ORM\Entity, ORM\InheritanceType('SINGLE_TABLE')]
+#[ORM\Entity]
+#[ORM\InheritanceType('SINGLE_TABLE')]
 #[ORM\DiscriminatorMap(['ONE' => 'SingleTableEntityNoDiscriminatorColumnMappingSub1', 'TWO' => 'SingleTableEntityNoDiscriminatorColumnMappingSub2'])]
 class SingleTableEntityNoDiscriminatorColumnMapping
 {
@@ -1683,7 +1746,9 @@ class SingleTableEntityNoDiscriminatorColumnMapping
      * @Column(type="integer")
      * @GeneratedValue(strategy="NONE")
      */
-    #[ORM\Id, ORM\Column(type: 'integer'), ORM\GeneratedValue(strategy: 'NONE')]
+    #[ORM\Id]
+    #[ORM\Column(type: 'integer')]
+    #[ORM\GeneratedValue(strategy: 'NONE')]
     public $id;
 
     public static function loadMetadata(ClassMetadata $metadata): void
@@ -1715,7 +1780,8 @@ class SingleTableEntityNoDiscriminatorColumnMappingSub2 extends SingleTableEntit
  * })
  * @DiscriminatorColumn(name="dtype")
  */
-#[ORM\Entity, ORM\InheritanceType('SINGLE_TABLE')]
+#[ORM\Entity]
+#[ORM\InheritanceType('SINGLE_TABLE')]
 #[ORM\DiscriminatorMap(['ONE' => 'SingleTableEntityNoDiscriminatorColumnMappingSub1', 'TWO' => 'SingleTableEntityNoDiscriminatorColumnMappingSub2'])]
 #[ORM\DiscriminatorColumn(name: 'dtype')]
 class SingleTableEntityIncompleteDiscriminatorColumnMapping
@@ -1726,7 +1792,9 @@ class SingleTableEntityIncompleteDiscriminatorColumnMapping
      * @Column(type="integer")
      * @GeneratedValue(strategy="NONE")
      */
-    #[ORM\Id, ORM\Column(type: 'integer'), ORM\GeneratedValue(strategy: 'NONE')]
+    #[ORM\Id]
+    #[ORM\Column(type: 'integer')]
+    #[ORM\GeneratedValue(strategy: 'NONE')]
     public $id;
 
     public static function loadMetadata(ClassMetadata $metadata): void
@@ -1759,7 +1827,9 @@ class ReservedWordInTableColumn
      * @Column(type="integer")
      * @GeneratedValue(strategy="NONE")
      */
-    #[ORM\Id, ORM\Column(type: 'integer'), ORM\GeneratedValue(strategy: 'NONE')]
+    #[ORM\Id]
+    #[ORM\Column(type: 'integer')]
+    #[ORM\GeneratedValue(strategy: 'NONE')]
     public $id;
 
     /**
@@ -1795,3 +1865,52 @@ class UserIncorrectAttributes extends User
 class UserMissingAttributes extends User
 {
 }
+
+
+/**
+ * @Entity
+ * @InheritanceType("SINGLE_TABLE")
+ * @DiscriminatorColumn(name="discr", enumType=GH10288People::class)
+ * @DiscriminatorMap({
+ *      "boss"     = GH10288EnumTypeBoss::class
+ * })
+ */
+#[Entity]
+#[InheritanceType('SINGLE_TABLE')]
+#[DiscriminatorColumn(name: 'discr', enumType: GH10288People::class)]
+#[DiscriminatorMap(['boss' => GH10288EnumTypeBoss::class])]
+abstract class GH10288EnumTypePerson
+{
+    /**
+     * @var int
+     * @Id
+     * @Column(type="integer")
+     * @GeneratedValue(strategy="AUTO")
+     */
+    public $id;
+
+    public static function loadMetadata(ClassMetadata $metadata): void
+    {
+        $metadata->mapField(
+            [
+                'id'                 => true,
+                'fieldName'          => 'id',
+            ]
+        );
+
+        $metadata->setDiscriminatorColumn(
+            [
+                'name'     => 'discr',
+                'enumType' =>  GH10288People::class,
+            ]
+        );
+
+        $metadata->setIdGeneratorType(ORM\ClassMetadataInfo::GENERATOR_TYPE_NONE);
+    }
+}
+
+/** @Entity */
+#[Entity]
+class GH10288EnumTypeBoss extends GH10288EnumTypePerson
+{
+}
