@@ -1,9 +1,13 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Doctrine\Tests\ORM\Mapping\NamingStrategy;
 
 use Doctrine\ORM\Mapping\DefaultNamingStrategy;
 
+use function strtolower;
+
 /**
  * Stub naming strategy to verify `joinColumnName` proper behavior
  */
