@@ -2,19 +2,19 @@
 
 declare(strict_types=1);
 
-use Doctrine\ORM\Mapping\ClassMetadataInfo;
+use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\Tests\Models\Cache\Attraction;
 use Doctrine\Tests\Models\Cache\State;
 use Doctrine\Tests\Models\Cache\Travel;
 
-$metadata->setInheritanceType(ClassMetadataInfo::INHERITANCE_TYPE_NONE);
+$metadata->setInheritanceType(ClassMetadata::INHERITANCE_TYPE_NONE);
 $metadata->setPrimaryTable(['name' => 'cache_city']);
-$metadata->setIdGeneratorType(ClassMetadataInfo::GENERATOR_TYPE_IDENTITY);
-$metadata->setChangeTrackingPolicy(ClassMetadataInfo::CHANGETRACKING_DEFERRED_IMPLICIT);
+$metadata->setIdGeneratorType(ClassMetadata::GENERATOR_TYPE_IDENTITY);
+$metadata->setChangeTrackingPolicy(ClassMetadata::CHANGETRACKING_DEFERRED_IMPLICIT);
 
 $metadata->enableCache(
     [
-        'usage' => ClassMetadataInfo::CACHE_USAGE_READ_ONLY,
+        'usage' => ClassMetadata::CACHE_USAGE_READ_ONLY,
     ]
 );
 
@@ -49,7 +49,7 @@ $metadata->mapOneToOne(
     ]
 );
 $metadata->enableAssociationCache('state', [
-    'usage' => ClassMetadataInfo::CACHE_USAGE_READ_ONLY,
+    'usage' => ClassMetadata::CACHE_USAGE_READ_ONLY,
 ]);
 
 $metadata->mapManyToMany(
@@ -69,5 +69,5 @@ $metadata->mapOneToMany(
     ]
 );
 $metadata->enableAssociationCache('attractions', [
-    'usage' => ClassMetadataInfo::CACHE_USAGE_READ_ONLY,
+    'usage' => ClassMetadata::CACHE_USAGE_READ_ONLY,
 ]);
