@@ -3,9 +3,9 @@
 declare(strict_types=1);
 
 use Doctrine\ORM\Events;
-use Doctrine\ORM\Mapping\ClassMetadataInfo;
+use Doctrine\ORM\Mapping\ClassMetadata;
 
-$metadata->setInheritanceType(ClassMetadataInfo::INHERITANCE_TYPE_JOINED);
+$metadata->setInheritanceType(ClassMetadata::INHERITANCE_TYPE_JOINED);
 $metadata->setTableName('company_contracts');
 $metadata->setDiscriminatorColumn(
     [
