@@ -2,11 +2,11 @@
 
 declare(strict_types=1);
 
-use Doctrine\ORM\Mapping\ClassMetadataInfo;
+use Doctrine\ORM\Mapping\ClassMetadata;
 
 $metadata->enableCache(
     [
-        'usage' => ClassMetadataInfo::CACHE_USAGE_READ_ONLY,
+        'usage' => ClassMetadata::CACHE_USAGE_READ_ONLY,
     ]
 );
 $metadata->mapManyToOne(
