@@ -22,6 +22,7 @@ use Doctrine\Persistence\Mapping\Driver\MappingDriver;
 use Doctrine\Persistence\Mapping\Driver\PHPDriver;
 use Doctrine\Tests\Mocks\EntityManagerMock;
 use Doctrine\Tests\OrmTestCase;
+use Doctrine\Tests\TestUtil;
 use Symfony\Component\Yaml\Parser;
 
 use function count;
@@ -62,11 +63,10 @@ abstract class ClassMetadataExporterTestCase extends OrmTestCase
             ->willReturn(new EventManager());
 
         $config = new Configuration();
-        $config->setProxyDir(__DIR__ . '/../../Proxies');
-        $config->setProxyNamespace('Doctrine\Tests\Proxies');
+        TestUtil::configureProxies($config);
         $config->setMetadataDriverImpl($metadataDriver);
 
-        return EntityManagerMock::create($connection, $config);
+        return new EntityManagerMock($connection, $config);
     }
 
     protected function createMetadataDriver(string $type, string $path): MappingDriver
