@@ -764,10 +764,9 @@ abstract class OrmFunctionalTestCase extends OrmTestCase
         //FIXME: two different configs! $conn and the created entity manager have
         // different configs.
         $config = new Configuration();
+        TestUtil::configureProxies($config);
         $config->setMetadataCache(self::$metadataCache);
         $config->setQueryCache(self::$queryCache);
-        $config->setProxyDir(__DIR__ . '/Proxies');
-        $config->setProxyNamespace('Doctrine\Tests\Proxies');
 
         if ($this->resultCache !== null) {
             $config->setResultCache($this->resultCache);
@@ -809,7 +808,7 @@ abstract class OrmFunctionalTestCase extends OrmTestCase
 
         // get rid of more global state
         $evm = $conn->getEventManager();
-        foreach ($evm->getListeners() as $event => $listeners) {
+        foreach ($evm->getAllListeners() as $event => $listeners) {
             foreach ($listeners as $listener) {
                 $evm->removeEventListener([$event], $listener);
             }
@@ -830,7 +829,7 @@ abstract class OrmFunctionalTestCase extends OrmTestCase
             $evm->addEventListener(['onFlush'], new DebugUnitOfWorkListener());
         }
 
-        return EntityManager::create($conn, $config);
+        return new EntityManager($conn, $config);
     }
 
     final protected function createSchemaManager(): AbstractSchemaManager
